@@ -411,6 +411,7 @@ void DoMarkov (PANALYSIS panal)
 {
   PGIBBSDATA pgd = &panal->gd;
   PLEVEL     pLevel0 = panal->pLevels[0];
+  char       c;
   long       nThetas, nUpdateAt, nTotal;
   long       i, iter = 0;
   long       nIter = pgd->nMaxIter;  /* scheduled iterations of the sampler */
@@ -465,12 +466,8 @@ void DoMarkov (PANALYSIS panal)
       exit (0);
     } /* if */
 
-    /* skip the first line.  This allows a MC output file to be used
-       directly as a restart file. */
-    if (!fscanf (pfile, "%*[^\n]"))
-      ReportError (NULL, RE_READERROR | RE_FATAL, panal->gd.szGdata, NULL);
-    else 
-      getc(pfile);
+    /* skip the first line */
+    do { c = getc(pfile); } while (c != '\n');
 
     TraverseLevels (pLevel0, ReadData, pfile, NULL);
 
@@ -558,9 +555,9 @@ void DoMarkov (PANALYSIS panal)
        close the file when finished */
 
     if (pgd->nSimTypeFlag == 3)
-      ReadRestart2 (pgd->pfileRestart, nThetas, pgd->nInvTemperatures,
-                    pdMCVarVals, pdSum, prgdSumProd, &iter,
-                    &pgd->indexT, pgd->rgdlnPi);
+      ReadRestartTemper (pgd->pfileRestart, nThetas, pgd->nInvTemperatures,
+                         pdMCVarVals, pdSum, prgdSumProd, &iter,
+                         &pgd->indexT, pgd->rgdlnPi);
     else
       ReadRestart (pgd->pfileRestart, nThetas, pdMCVarVals, pdSum, prgdSumProd,
                    &iter);
@@ -1714,6 +1711,7 @@ void ReadRestart (FILE *pfileRestart, long nThetas,
                   double *pdTheta, double *pdSum, double **prgdSumProd,
                   long *pIter)
 {
+  register char c;
   register long i, j;
 
   *pIter = -1;
@@ -1724,12 +1722,9 @@ void ReadRestart (FILE *pfileRestart, long nThetas,
       prgdSumProd[i][j] = 0.0;
   }
 
-  /* skip the first line.  This allows a MC output file to be used
+  /* skip the first line. This allows a MC output file to be used
      directly as a restart file. */
-  if (!fscanf (pfileRestart,  "%*[^\n]")) 
-    ReportError (NULL, RE_READERROR | RE_FATAL, "Restart file", NULL);
-  else 
-    getc(pfileRestart);
+  do { c = getc(pfileRestart); } while (c != '\n');
 
   /* as long as we have not reached the end of the file we keep reading lines
      and overwriting the thetas, they keep only their last value.
@@ -1751,10 +1746,7 @@ void ReadRestart (FILE *pfileRestart, long nThetas,
 
     /* Throw away remainder of line. This allows a MC output file to be used
        directly as a restart file. */
-    if (!fscanf (pfileRestart,  "%*[^\n]")) 
-      ReportError (NULL, RE_READERROR | RE_FATAL, "Restart file", NULL);
-    else
-      getc(pfileRestart);
+    do { c = getc(pfileRestart); } while (c != '\n');
 
     /* update prgdSumProd */
     for (i = 0; i < nThetas; i++)
@@ -1773,17 +1765,19 @@ void ReadRestart (FILE *pfileRestart, long nThetas,
 
 } /* ReadRestart */
 
+
 /* Function -------------------------------------------------------------------
-   ReadRestart2
+   ReadRestartTemper
 
    initialize parameters and temperature stuff (pseudoprior, indexT) by reading
    them in the restart file.
    */
 
-void ReadRestart2 (FILE *pfileRestart, long nThetas, int nInvTemperatures,
-                  double *pdTheta, double *pdSum, double **prgdSumProd,
-                  long *pIter, long *pindexT, double *pdlnPi)
+void ReadRestartTemper (FILE *pfileRestart, long nThetas, int nInvTemperatures,
+                        double *pdTheta, double *pdSum, double **prgdSumProd,
+                        long *pIter, long *pindexT, double *pdlnPi)
 {
+  register char c;
   register long i, j;
   double aux[nInvTemperatures];
   long iT;
@@ -1799,10 +1793,7 @@ void ReadRestart2 (FILE *pfileRestart, long nThetas, int nInvTemperatures,
 
   /* skip the first line. This allows a MC output file to be used
      directly as a restart file. */
-  if (!fscanf (pfileRestart, "%*[^\n]"))
-    ReportError (NULL, RE_READERROR | RE_FATAL, "Restart file", NULL);
-  else
-    getc(pfileRestart);
+  do { c = getc(pfileRestart); } while (c != '\n');
 
   /* as long as we have not reached the end of the file we keep reading lines
      and overwriting the thetas, they keep only their last value.
@@ -1821,23 +1812,21 @@ void ReadRestart2 (FILE *pfileRestart, long nThetas, int nInvTemperatures,
       }
     }
 
-     if (fscanf(pfileRestart,"%ld", &(iT)) == EOF) {
+    if (fscanf(pfileRestart,"%ld", &(iT)) == EOF) {
+      printf ("Error: incorrect length for restart file - Exiting\n");
+      exit(0);
+    }
+
+    for (i = 0; i < nInvTemperatures; i++) {
+      if (fscanf(pfileRestart,"%lg", &(aux[i])) == EOF) {
         printf ("Error: incorrect length for restart file - Exiting\n");
         exit(0);
-     }
-     for (i = 0; i < nInvTemperatures; i++) {
-       if (fscanf(pfileRestart,"%lg", &(aux[i])) == EOF) {
-         printf ("Error: incorrect length for restart file - Exiting\n");
-         exit(0);
-       }
-     }
+      }
+    }
 
     /* Throw away remainder of line. This allows a MC output file to be used
        directly as a restart file. */
-    if (!fscanf (pfileRestart,  "%*[^\n]")) 
-      ReportError (NULL, RE_READERROR | RE_FATAL, "Restart file", NULL);
-    else
-      getc(pfileRestart);
+    do { c = getc(pfileRestart); } while (c != '\n');
 
     *pindexT = iT;
     for (i = 0; i < nInvTemperatures; i++) 
@@ -1848,7 +1837,6 @@ void ReadRestart2 (FILE *pfileRestart, long nThetas, int nInvTemperatures,
       for (j = 0; j < nThetas; j++)
         prgdSumProd[i][j] = prgdSumProd[i][j] + pdTheta[i] * pdTheta[j];
 
-
     /* increment pIter */
     *pIter = *pIter + 1;
 
@@ -1858,7 +1846,7 @@ void ReadRestart2 (FILE *pfileRestart, long nThetas, int nInvTemperatures,
 
   fclose (pfileRestart);
 
-} /* ReadRestart2 */
+} /* ReadRestartTemper */
 
 
 /* Function -------------------------------------------------------------------
