@@ -423,8 +423,8 @@ BOOL GetInvTemperature (PINPUTBUF pibIn, PSTR szLex, PGIBBSDATA pgd)
     /* initialize */
     pgd->rgdlnPi[i] = 0;
     pgd->rglTemp[i] = 0; /* temperature count*/
-    if ((pgd->rgInvTemperatures[i] <= 0) || (pgd->rgInvTemperatures[i] > 1))
-      ReportError (pibIn, RE_LEXEXPECTED | RE_FATAL, "number in ]0,1]", szLex);
+    if ((pgd->rgInvTemperatures[i] < 0) || (pgd->rgInvTemperatures[i] > 1))
+      ReportError (pibIn, RE_LEXEXPECTED | RE_FATAL, "number in [0,1]", szLex);
     if ((i > 0) && (pgd->rgInvTemperatures[i] <= pgd->rgInvTemperatures[i-1]))
       ReportError (pibIn, RE_LEXEXPECTED | RE_FATAL, 
                    "lower number", szLex);
@@ -436,7 +436,7 @@ Exit_GetInvTemperatures:
 
   if (bErr)
     printf ("Syntax: Inverse temperatures (nInvTemperatures, "
-            "<n inverse temperature values in ]0,1] interval>)\n\n");
+            "<n inverse temperature values in [0,1] interval>)\n\n");
 
   return (!bErr);
 
