@@ -262,6 +262,7 @@ void CalcMCParms (PMONTECARLO pMC, double rgParms[], long iStart)
 
 BOOL InitSetPoints (PMONTECARLO pMC)
 {
+  register char c;
   PFILE pfile;
 
   if (!(pfile = fopen(pMC->szSetPointsFilename, "r")))
@@ -272,16 +273,11 @@ BOOL InitSetPoints (PMONTECARLO pMC)
 
   /* Throw away the first line.  This allows a MC output file to be used
      directly as a setpoints file. */
-  if (!fscanf (pMC->pfileSetPoints,  "%*[^\n]")) {
-    if (feof(pMC->pfileSetPoints))
-      ReportError (NULL, RE_INSUF_POINTS | RE_FATAL,
-                   pMC->szSetPointsFilename, NULL);
-    else
-      ReportError (NULL, RE_READERROR | RE_FATAL,
-                   pMC->szSetPointsFilename, NULL);
-  }
-  else
-    getc(pMC->pfileSetPoints);
+  do { c = getc(pMC->pfileSetPoints); } while (c != '\n');
+
+  if (feof(pMC->pfileSetPoints))
+    ReportError (NULL, RE_INSUF_POINTS | RE_FATAL,
+                 pMC->szSetPointsFilename, NULL);
 
   return (!pfile);
 
@@ -299,6 +295,7 @@ BOOL InitSetPoints (PMONTECARLO pMC)
 BOOL ReadSetPoints (PMONTECARLO pMC, double rgParms[])
 {
   BOOL bReturn = FALSE; /* Initially, flag no points read */
+  register char c;
   long i;
 
   if (!rgParms)
@@ -331,13 +328,9 @@ BOOL ReadSetPoints (PMONTECARLO pMC, double rgParms[])
 
   bReturn = TRUE; /* Flag that all parms were read */
 
-  /* Throw away remainder of line.  This allows a MC output file to be used
-     directly as a setpoints file.  */
-  if (!fscanf (pMC->pfileSetPoints,  "%*[^\n]")) {
-    ReportError (NULL, RE_READERROR | RE_FATAL, pMC->szSetPointsFilename, NULL);
-  }
-  else 
-    getc(pMC->pfileSetPoints);
+  /* Throw away remainder of line. This allows a MC output file to be used
+     directly as a setpoints file. */
+  do { c = getc(pMC->pfileSetPoints); } while (c != '\n');
 
 Exit_ReadSetPoints:
   ;
